Package: conf
Type: Package
Title: Visualization and Analysis of Statistical Measures of Confidence
Version: 1.9.3
Authors@R: c(person("Christopher", "Weld", role = c("aut", "cre"), email = "ceweld241@gmail.com", comment = c(ORCID = "0000-0001-5902-9738")), 
  person("Kexin", "Feng", role = "aut"),
  person("Hayeon", "Park", role = "aut"),
  person("Yuxin", "Qin", role = "aut"), 
  person("Xingyu", "Wang", role = "aut"),
  person("Heather", "Krehbiel", role = "aut"),
  person("Lawrence", "Leemis", role = "aut"),
  person("Yuan", "Chang", role = "ctb"),
  person("Brock", "Crook", role = "ctb"),
  person("Chris", "Kuebler", role = "ctb"),
  person("Andrew", "Loh", role = "ctb"),
  person("Xin", "Zhang", role = "ctb")) 
Maintainer: Christopher Weld <ceweld241@gmail.com>
Imports: graphics, stats, statmod, fitdistrplus, pracma, rootSolve,
        utils
Description: Enables: (1) plotting two-dimensional confidence regions, (2) coverage analysis
  of confidence region simulations, (3) calculating confidence intervals and the associated 
  actual coverage for binomial proportions, (4) calculating the support values and the 
  probability mass function of the Kaplan-Meier product-limit estimator, and (5) plotting
  the actual coverage function associated with a confidence interval for the survivor
  function from a randomly right-censored data set. Each is given in greater detail next. 
  (1) Plots the two-dimensional confidence region for probability distribution parameters 
  (supported distribution suffixes: cauchy, gamma, invgauss, logis, llogis, lnorm, norm, unif, 
  weibull) corresponding to a user-given complete or right-censored dataset and level of 
  significance.  The crplot() algorithm plots more points in areas of greater curvature to 
  ensure a smooth appearance throughout the confidence region boundary.  An alternative 
  heuristic plots a specified number of points at roughly uniform intervals along its boundary. 
  Both heuristics build upon the radial profile log-likelihood ratio technique for plotting 
  confidence regions given by Jaeger (2016) <doi:10.1080/00031305.2016.1182946>, and
  are detailed in a publication by Weld et al. (2019) <doi:10.1080/00031305.2018.1564696>. 
  (2) Performs confidence region coverage simulations for a random sample drawn from a user-
  specified parametric population distribution, or for a user-specified dataset and point of 
  interest with coversim(). (3) Calculates confidence interval bounds for a binomial proportion 
  with binomTest(), calculates the actual coverage with binomTestCoverage(), and plots the 
  actual coverage with binomTestCoveragePlot(). Calculates confidence interval bounds for the
  binomial proportion using an ensemble of constituent confidence intervals with 
  binomTestEnsemble(). Calculates confidence interval bounds for the binomial proportion using 
  a complete enumeration of all possible transitions from one actual coverage acceptance curve 
  to another which minimizes the root mean square error for n <= 15 and follows the transitions 
  for well-known confidence intervals for n > 15 using binomTestMSE(). (4) The km.support() 
  function calculates the support values of the Kaplan-Meier product-limit estimator for a given 
  sample size n using an induction algorithm described in Qin et al. (2023) 
  <doi:10.1080/00031305.2022.2070279>. The km.outcomes() function generates a matrix 
  containing all possible outcomes (all possible sequences of failure times and right-censoring 
  times) of the value of the Kaplan-Meier product-limit estimator for a particular sample size 
  n. The km.pmf() function generates the probability mass function for the support values of 
  the Kaplan-Meier product-limit estimator for a particular sample size n, probability of 
  observing a failure h at the time of interest expressed as the cumulative probability 
  percentile associated with X = min(T, C), where T is the failure time and C is the censoring 
  time under a random-censoring scheme. The km.surv() function generates multiple probability 
  mass functions of the Kaplan-Meier product-limit estimator for the same arguments as those 
  given for km.pmf(). (5) The km.coverage() function plots the actual coverage function
  associated with a confidence interval for the survivor function from a randomly right-censored
  data set for one or more of the following confidence intervals: Greenwood, log-minus-log,
  Peto, arcsine, and exponential Greenwood.  The actual coverage function is plotted for a
  small number of items on test, stated coverage, failure rate, and censoring rate. The 
  km.coverage() function can print an optional table containing all possible
  failure/censoring orderings, along with their contribution to the actual coverage function.
Depends: R (>= 4.0.0)
License: GPL (<= 2)
Encoding: UTF-8
RoxygenNote: 7.3.2
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
Language: en-US
NeedsCompilation: no
Packaged: 2026-03-02 15:16:58 UTC; christopherweld
Author: Christopher Weld [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-5902-9738>),
  Kexin Feng [aut],
  Hayeon Park [aut],
  Yuxin Qin [aut],
  Xingyu Wang [aut],
  Heather Krehbiel [aut],
  Lawrence Leemis [aut],
  Yuan Chang [ctb],
  Brock Crook [ctb],
  Chris Kuebler [ctb],
  Andrew Loh [ctb],
  Xin Zhang [ctb]
Repository: CRAN
Date/Publication: 2026-03-02 15:40:02 UTC
Built: R 4.6.0; ; 2026-04-27 15:53:13 UTC; unix
