# Generated by roxygen2: do not edit by hand

S3method(coef,durationFit)
S3method(logLik,durationFit)
export(binomTest)
export(binomTestCoverage)
export(binomTestCoveragePlot)
export(binomTestEnsemble)
export(binomTestMSE)
export(coversim)
export(crplot)
export(dinvgauss)
export(dllogis)
export(gammaMLE)
export(invgaussMLE)
export(km.coverage)
export(km.outcomes)
export(km.pmf)
export(km.support)
export(km.surv)
export(llogisMLE)
export(pinvgauss)
export(pllogis)
export(qinvgauss)
export(qllogis)
export(rinvgauss)
export(rllogis)
import(graphics)
import(rootSolve)
import(stats)
importFrom(fitdistrplus,mledist)
importFrom(pracma,inpolygon)
importFrom(statmod,dinvgauss)
importFrom(statmod,pinvgauss)
importFrom(statmod,qinvgauss)
importFrom(statmod,rinvgauss)
importFrom(utils,capture.output)
importFrom(utils,flush.console)
