## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----fig.width = 4, fig.height = 4, fig.show = 'hold'-------------------------
library(conf)
#  display the outcomes and KMPLE for n = 4 items on test
n = 4
km.outcomes(n)


